import React, { useState } from 'react';
import OgmaWrapper from './OgmaWrapper.jsx';
import Tooltip from './Tooltip.jsx';

export default function App() {
  const [graph, setGraph] = useState({
    nodes: [{ id: 0 }],
    edges: []
  });

  const [currentNode, setCurrentNode] = useState(null);
  const [tooltipPosition, setTooltipPosition] = useState({ x: 0, y: 0 });
  const [tooltipData, setTooltipData] = useState(null);

  function addNode() {
    if (graph.nodes.length === 0) {
      return setGraph({
        nodes: [{ id: 0 }],
        edges: []
      });
    }
    const lastNode = graph.nodes[graph.nodes.length - 1];
    setGraph({
      nodes: [
        ...graph.nodes,
        {
          id: graph.nodes.length
        }
      ],
      edges: [
        ...graph.edges,
        { source: lastNode.id, target: graph.nodes.length }
      ]
    });
  }

  function removeNode() {
    const r = graph.nodes.pop();
    setGraph({
      nodes: [...graph.nodes],
      edges: [
        ...graph.edges.filter(e => e.source !== r.id && e.target !== r.id)
      ]
    });
  }

  function onNodeHover(target) {
    if (target) {
      const { node, position } = target;
      setTooltipData(node.getData() || {});
      setTooltipPosition({
        x: position.x + 10,
        y: position.y + 10
      });
    } else {
      setTooltipData(null); //setTooltipPos
    }
  }

  return (
    <div className="App">
      <section className="App-vis">
        <OgmaWrapper
          graph={graph}
          onNodeClick={setCurrentNode}
          onNodeHover={onNodeHover}
        />
        {tooltipData && (
          <Tooltip position={tooltipPosition} data={tooltipData} />
        )}
        <div className="App-data">
          <button onClick={addNode}>Add node</button>
          <button onClick={removeNode}>Remove node</button>
          <div>
            <div>
              Clicked node: {currentNode === null ? 'none' : currentNode}
            </div>
            <code>
              <pre>{JSON.stringify(graph, 0, 2)}</pre>
            </code>
          </div>
        </div>
      </section>
    </div>
  );
}
