import Ogma from '@linkurious/ogma';
import React, { useEffect, useRef } from 'react';

export default function OgmaWrapper({ graph, onNodeClick, onNodeHover }) {
  const containerId = 'ogma-container';
  // initialize ogma and get a reference to it
  const ogmaRef = useRef(null);
  useEffect(() => {
    ogmaRef.current = new Ogma({ container: containerId });
  }, []);

  // setup events and more
  useEffect(() => {
    // as suggested by react debug tools, due to ref lifecycle
    const ogma = ogmaRef.current;
    const clickHandler = ({ target }) => {
      if (target && target.isNode) {
        onNodeClick(target.getId());
      } else {
        onNodeClick(null);
      }
    };
    const container = ogma.getContainer();
    const hoverHandler = ({ target }) => {
      if (target && target.isNode) {
        const pos = target.getPositionOnScreen();
        onNodeHover({
          node: target,
          position: {
            x: pos.x + container.offsetLeft,
            y: pos.y + container.offsetTop
          }
        });
      }
    };
    const outHandler = () => onNodeHover(null);

    ogma.events
      .on('click', clickHandler)
      .on('mouseover', hoverHandler)
      .on('mouseout', outHandler);
    return () => {
      ogma.events.off(clickHandler);
      ogma.events.off(hoverHandler);
      ogma.events.off(outHandler);
    };
  }, [onNodeClick, onNodeHover]);

  // update graph
  useEffect(() => {
    const nodeSettings = { attributes: ['x', 'y', 'radius'] };
    const edgeSettings = { attributes: ['width'] };
    ogmaRef.current.clearGraph();
    ogmaRef.current
      .setGraph(graph)
      .then(() =>
        ogmaRef.current.layouts.force({ locate: graph.nodes.length !== 0 })
      )
      // primitive tracking of the current attributes
      // this is where you can send the updates to your state management,
      // e.g. redux, etc
      .then(() => {
        graph.nodes = ogmaRef.current.getNodes().toJSON(nodeSettings);
        graph.edges = ogmaRef.current.getEdges().toJSON(edgeSettings);
      });
  }, [graph]);

  return (
    <div className="OgmaWrapper">
      <div id={containerId} />
    </div>
  );
}
